Class: Aws::MigrationHubConfig::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MigrationHubConfig::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-migrationhubconfig/client.rb,
sig/client.rbs
Overview
An API client for MigrationHubConfig. To construct a client, you need to configure a :region and :credentials.
client = Aws::MigrationHubConfig::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateHomeRegionControlResponseSuccess, _DeleteHomeRegionControlResponseSuccess, _DescribeHomeRegionControlsResponseSuccess, _GetHomeRegionResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_home_region_control(params = {}) ⇒ Types::CreateHomeRegionControlResult
This API sets up the home region for the calling account only.
-
#delete_home_region_control(params = {}) ⇒ Struct
This operation deletes the home region configuration for the calling account.
-
#describe_home_region_controls(params = {}) ⇒ Types::DescribeHomeRegionControlsResult
This API permits filtering on the
ControlIdandHomeRegionfields. -
#get_home_region(params = {}) ⇒ Types::GetHomeRegionResult
Returns the calling account’s home region, if configured.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-migrationhubconfig/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
671 672 673 |
# File 'lib/aws-sdk-migrationhubconfig/client.rb', line 671 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
674 675 676 |
# File 'lib/aws-sdk-migrationhubconfig/client.rb', line 674 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 |
# File 'lib/aws-sdk-migrationhubconfig/client.rb', line 644 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MigrationHubConfig') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-migrationhubconfig' context[:gem_version] = '1.68.0' Seahorse::Client::Request.new(handlers, context) end |
#create_home_region_control(params = {}) ⇒ Types::CreateHomeRegionControlResult
This API sets up the home region for the calling account only.
87 |
# File 'sig/client.rbs', line 87
def create_home_region_control: (
|
#delete_home_region_control(params = {}) ⇒ Struct
This operation deletes the home region configuration for the calling account. The operation does not delete discovery or migration tracking data in the home region.
101 |
# File 'sig/client.rbs', line 101
def delete_home_region_control: (
|
#describe_home_region_controls(params = {}) ⇒ Types::DescribeHomeRegionControlsResult
This API permits filtering on the ControlId and HomeRegion fields.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
112 |
# File 'sig/client.rbs', line 112
def describe_home_region_controls: (
|
#get_home_region(params = {}) ⇒ Types::GetHomeRegionResult
Returns the calling account’s home region, if configured. This API is
used by other AWS services to determine the regional endpoint for
calling AWS Application Discovery Service and Migration Hub. You must
call GetHomeRegion at least once before you call any other AWS
Application Discovery Service and AWS Migration Hub APIs, to obtain
the account's Migration Hub home region.
129 |
# File 'sig/client.rbs', line 129
def get_home_region: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
664 665 666 |
# File 'lib/aws-sdk-migrationhubconfig/client.rb', line 664 def waiter_names [] end |